pub struct RatingLeaderboardRequest {
pub character_id: Uuid,
pub rating_type: RatingType,
pub limit: i64,
pub offset: i64,
}Fields
character_id: Uuidrating_type: RatingTypelimit: i64offset: i64Trait Implementations
Sourceimpl Clone for RatingLeaderboardRequest
impl Clone for RatingLeaderboardRequest
Sourcefn clone(&self) -> RatingLeaderboardRequest
fn clone(&self) -> RatingLeaderboardRequest
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RatingLeaderboardRequest
impl Debug for RatingLeaderboardRequest
Sourceimpl<'de> Deserialize<'de> for RatingLeaderboardRequest
impl<'de> Deserialize<'de> for RatingLeaderboardRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<RatingLeaderboardRequest> for JsValuewhere
RatingLeaderboardRequest: Serialize,
impl From<RatingLeaderboardRequest> for JsValuewhere
RatingLeaderboardRequest: Serialize,
Sourcefn from(value: RatingLeaderboardRequest) -> Self
fn from(value: RatingLeaderboardRequest) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for RatingLeaderboardRequestwhere
Self: DeserializeOwned,
impl FromWasmAbi for RatingLeaderboardRequestwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for RatingLeaderboardRequestwhere
RatingLeaderboardRequest: Serialize,
impl IntoWasmAbi for RatingLeaderboardRequestwhere
RatingLeaderboardRequest: Serialize,
Sourceimpl JsonSchema for RatingLeaderboardRequest
impl JsonSchema for RatingLeaderboardRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for RatingLeaderboardRequestwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for RatingLeaderboardRequestwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for RatingLeaderboardRequestwhere
RatingLeaderboardRequest: Serialize,
impl OptionIntoWasmAbi for RatingLeaderboardRequestwhere
RatingLeaderboardRequest: Serialize,
Sourceimpl PartialEq for RatingLeaderboardRequest
impl PartialEq for RatingLeaderboardRequest
Sourceimpl RefFromWasmAbi for RatingLeaderboardRequestwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for RatingLeaderboardRequestwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<RatingLeaderboardRequest>
type Anchor = SelfOwner<RatingLeaderboardRequest>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for RatingLeaderboardRequest
impl Serialize for RatingLeaderboardRequest
Sourceimpl Tsify for RatingLeaderboardRequest
impl Tsify for RatingLeaderboardRequest
const DECL: &'static str = "export interface RatingLeaderboardRequest {\n character_id: Uuid;\n rating_type: RatingType;\n limit: number;\n offset: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for RatingLeaderboardRequestwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for RatingLeaderboardRequestwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for RatingLeaderboardRequestwhere
RatingLeaderboardRequest: Serialize,
impl VectorIntoWasmAbi for RatingLeaderboardRequestwhere
RatingLeaderboardRequest: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for RatingLeaderboardRequest
impl WasmDescribeVector for RatingLeaderboardRequest
impl Eq for RatingLeaderboardRequest
impl StructuralPartialEq for RatingLeaderboardRequest