pub struct RatingRangeReward {
pub mail_template_id: Option<MailTemplateId>,
pub diapason_start: i64,
pub diapason_end: Option<i64>,
}Fields
mail_template_id: Option<MailTemplateId>diapason_start: i64diapason_end: Option<i64>Trait Implementations
Sourceimpl Clone for RatingRangeReward
impl Clone for RatingRangeReward
Sourcefn clone(&self) -> RatingRangeReward
fn clone(&self) -> RatingRangeReward
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RatingRangeReward
impl Debug for RatingRangeReward
Sourceimpl<'de> Deserialize<'de> for RatingRangeReward
impl<'de> Deserialize<'de> for RatingRangeReward
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for RatingRangeReward
impl Hash for RatingRangeReward
Sourceimpl JsonSchema for RatingRangeReward
impl JsonSchema for RatingRangeReward
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RatingRangeReward
impl PartialEq for RatingRangeReward
Sourceimpl Serialize for RatingRangeReward
impl Serialize for RatingRangeReward
Sourceimpl Tsify for RatingRangeReward
impl Tsify for RatingRangeReward
const DECL: &'static str = "export interface RatingRangeReward {\n mail_template_id: MailTemplateId | null;\n diapason_start: number;\n diapason_end: number | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for RatingRangeReward
impl StructuralPartialEq for RatingRangeReward