pub struct RatingRankingItem {
pub user: User,
pub character: Character,
pub place: u64,
}Fields
user: Usercharacter: Characterplace: u64Trait Implementations
Sourceimpl Clone for RatingRankingItem
impl Clone for RatingRankingItem
Sourcefn clone(&self) -> RatingRankingItem
fn clone(&self) -> RatingRankingItem
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for RatingRankingItem
impl CustomType for RatingRankingItem
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for RatingRankingItem
impl Debug for RatingRankingItem
Sourceimpl<'de> Deserialize<'de> for RatingRankingItem
impl<'de> Deserialize<'de> for RatingRankingItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RatingRankingItem
impl JsonSchema for RatingRankingItem
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RatingRankingItem
impl PartialEq for RatingRankingItem
Sourceimpl Serialize for RatingRankingItem
impl Serialize for RatingRankingItem
Sourceimpl Tsify for RatingRankingItem
impl Tsify for RatingRankingItem
const DECL: &'static str = "export interface RatingRankingItem {\n user: User;\n character: Character;\n place: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for RatingRankingItem
impl StructuralPartialEq for RatingRankingItem