pub struct RatingSettings {
pub id: RatingId,
pub rating_type: RatingType,
pub rating_range_rewards: Vec<RatingRangeReward>,
}Fields
id: RatingIdrating_type: RatingTyperating_range_rewards: Vec<RatingRangeReward>Trait Implementations
Sourceimpl Clone for RatingSettings
impl Clone for RatingSettings
Sourcefn clone(&self) -> RatingSettings
fn clone(&self) -> RatingSettings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RatingSettings
impl Debug for RatingSettings
Sourceimpl<'de> Deserialize<'de> for RatingSettings
impl<'de> Deserialize<'de> for RatingSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for RatingSettings
impl Hash for RatingSettings
Sourceimpl JsonSchema for RatingSettings
impl JsonSchema for RatingSettings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RatingSettings
impl PartialEq for RatingSettings
Sourceimpl Serialize for RatingSettings
impl Serialize for RatingSettings
Sourceimpl Tsify for RatingSettings
impl Tsify for RatingSettings
const DECL: &'static str = "export interface RatingSettings {\n id: RatingId;\n rating_type: RatingType;\n rating_range_rewards: RatingRangeReward[];\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for RatingSettings
impl StructuralPartialEq for RatingSettings